'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _lfsCommands = require('./lfsCommands');

var _constants = require('../constants');

var _generateResponse = require('../utils/generateResponse');

var _generateResponse2 = _interopRequireDefault(_generateResponse);

var _helpers = require('../helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isValidLine = function isValidLine(str) {
  return str !== '';
};

var generateFetchStats = function generateFetchStats(raw) {
  if (raw && typeof raw === 'string') {
    var stats = {};
    var outputLines = raw.split('Git LFS:');
    var filteredLines = _ramda2.default.filter(isValidLine, outputLines);
    var statLine = filteredLines.pop();

    var byteResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_BYTES);

    stats.total_bytes_fetched = byteResults !== null ? byteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    stats.total_bytes = byteResults !== null ? byteResults[1].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var fileResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_FILES);

    stats.total_files_fetched = fileResults !== null ? fileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var skippedByteResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_BYTES);

    stats.total_bytes_skipped = skippedByteResults !== null ? skippedByteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    var skippedFileResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_FILES);

    stats.total_files_skipped = skippedFileResults !== null ? skippedFileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

    (0, _helpers.verifyOutput)(stats, raw);

    if (statLine.includes('error:')) {
      stats.fetch_error = statLine.split('error:')[1].trim();
    }

    return stats;
  }
  return {};
};

function fetch(repo, options) {
  var response = (0, _generateResponse2.default)();
  var repoPath = repo.workdir();

  var args = [];

  var _ref = options || {},
      remoteName = _ref.remoteName,
      branchName = _ref.branchName,
      callback = _ref.callback;

  if (remoteName) {
    args.push(remoteName);
  }

  if (branchName) {
    args.push(branchName);
  }

  var argsString = _ramda2.default.join(' ', args);
  return _lfsCommands.core.fetch(argsString, { cwd: repoPath, shell: true }, callback).then(function (_ref2) {
    var stdout = _ref2.stdout;

    response.raw = stdout;
    response.fetch = generateFetchStats(stdout);

    if (response.fetch.fetch_error) {
      response.success = false;
      response.stderr = response.fetch.fetch_error;
      response.errno = _constants.BAD_CORE_RESPONSE;
    }

    return response;
  }, (0, _helpers.errorCatchHandler)(response));
}

exports.default = fetch;