'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _lfsCommands = require('./lfsCommands');

var _constants = require('../constants');

var _generateResponse = require('../utils/generateResponse');

var _generateResponse2 = _interopRequireDefault(_generateResponse);

var _helpers = require('../helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Note to future maintainers, I do not like this; at all. But at the moment this is the
 * best we got, inorder to parse the result from git core. Any slight change to the LFS output
 * in subsequent versions of CORE for LFS, will surely break this. Until we migrate off
 * git core dependency, we will have to regex the output. Godspeed.
 */

var isValidLine = function isValidLine(str) {
  return str !== '';
};

var generatePushStats = function generatePushStats(raw) {
  if (!raw || typeof raw !== 'string') {
    return {
      error: 'invalid output'
    };
  }
  var stats = {};

  var outputLines = raw.split('Git LFS:');
  var filteredLines = _ramda2.default.filter(isValidLine, outputLines);
  var statLine = filteredLines.pop();

  var byteResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_BYTES);

  stats.total_bytes_transferred = byteResults !== null ? byteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

  stats.total_bytes = byteResults !== null ? byteResults[1].trim() : _constants.BAD_REGEX_PARSE_RESULT;

  var fileResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_FILES);

  stats.total_files_transferred = fileResults !== null ? fileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

  var skippedByteResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_BYTES);

  stats.total_bytes_skipped = skippedByteResults !== null ? skippedByteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

  var skippedFileResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_FILES);

  stats.total_files_skipped = skippedFileResults !== null ? skippedFileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;

  (0, _helpers.verifyOutput)(stats, raw);

  if (statLine.includes('error:')) {
    stats.error = statLine.split('error:')[1].trim();
  }

  return stats;
};

function push(repo, options) {
  var _this = this;

  var response = (0, _generateResponse2.default)();
  var repoPath = repo.workdir();

  var _ref = options || {},
      remoteName = _ref.remoteName,
      branchName = _ref.branchName,
      callback = _ref.callback;

  var branch = branchName;
  var remote = remoteName;
  var getRemoteAndBranchPromise = Promise.resolve();

  if (!remote || !branch) {
    var remoteRef = void 0;
    getRemoteAndBranchPromise = repo.getCurrentBranch().then(function (Reference) {
      var promises = [];
      promises.push(_this.NodeGit.Branch.upstream(Reference));
      promises.push(_this.NodeGit.Branch.name(Reference));
      return Promise.all(promises);
    }).then(function (results) {
      remoteRef = results[0];
      branch = branch || results[1];
      return _this.NodeGit.Branch.remoteName(repo, remoteRef.name());
    }).then(function (name) {
      remote = remote || name;
      return Promise.resolve();
    });
  }

  return getRemoteAndBranchPromise.then(function () {
    return _lfsCommands.core.push(remote + ' ' + branch, { cwd: repoPath }, callback);
  }).then(function (_ref2) {
    var stdout = _ref2.stdout;

    response.raw = stdout;
    response.push = generatePushStats(stdout);
    return response;
  }, (0, _helpers.errorCatchHandler)(response));
}

exports.default = push;