'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _lfsCommands = require('./lfsCommands');

var _generateResponse = require('../utils/generateResponse');

var _generateResponse2 = _interopRequireDefault(_generateResponse);

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isString = function isString(str) {
  return typeof str === 'string';
};
var ticks = process.platform === 'win32' ? '"' : "'";

var extractGlobs = function extractGlobs(input, regex) {
  var matches = input.match(regex);
  if (!matches || _ramda2.default.isEmpty(matches)) {
    return [];
  }
  return matches;
};

var track = function track(repo, globs) {
  if (!globs) {
    return;
  }

  var filteredGlobs = _ramda2.default.pipe(_ramda2.default.filter(isString), _ramda2.default.map(function (g) {
    return '' + ticks + g + ticks;
  }))(globs);
  var response = (0, _generateResponse2.default)();
  var repoPath = repo.workdir();

  return _lfsCommands.core.track(_ramda2.default.join(' ', filteredGlobs), { cwd: repoPath }).then(function (_ref) {
    var stdout = _ref.stdout,
        stderr = _ref.stderr;

    response.raw = stdout;

    if (stderr) {
      response.success = false;
      response.errno = _constants.BAD_CORE_RESPONSE;
      response.stderr = stderr;
      return response;
    }

    response.new_globs = extractGlobs(stdout, _constants.regex.TRACK);
    return response;
  });
};

exports.default = track;